@@ -5,7 +5,7 @@
 #' @examples \dontrun{
 #' vcr_configure(dir = tempdir())
 #'
-#'
+#' # basic example of VcrResponse use
 #' url <- "https://google.com"
 #' (cli <- crul::HttpClient$new(url = url))
 #' (res <- cli$get("get", query = list(q = "stuff")))
@@ -18,7 +18,6 @@
 #' x$to_hash()
 #' x$from_hash(x$to_hash())
 #'
-#'
 #' # update content length header
 #' ## example 1
 #' ### content-length header present, but no change
@@ -32,15 +31,28 @@
 #' x$headers$`content-length`
 #'
 #' ## example 2
-#' ### no content-length header
+#' ### no content-length header b/c a transfer-encoding header is included
+#' ### and no content-length header allowed if transfer-encoding header
+#' ### used (via rfc7230)
 #' url <- "https://google.com"
 #' cli <- crul::HttpClient$new(url = url)
 #' res <- cli$get()
 #' x <- VcrResponse$new(res$status_http(), res$response_headers,
 #'    rawToChar(res$content), res$response_headers$status)
-#' x$headers$`content-length`
+#' x$headers$`content-length` # = NULL
 #' x$update_content_length_header() # no change, b/c header doesn't exist
-#'
+#' x$headers$`content-length` # = NULL
+#' 
+#' ## example 3
+#' ### content-length header present, and does change
+#' body <- " Hello World "
+#' x <- VcrResponse$new(200, list('content-length'=nchar(body)),
+#'   body, "HTTP/2")
+#' x$headers$`content-length` # = 13
+#' x$body <- gsub("^\\s|\\s$", "", x$body)
+#' x$headers$`content-length` # = 13
+#' x$update_content_length_header()
+#' x$headers$`content-length` # = 11
 #'
 #' # check if body is compressed
 #' url <- "https://fishbase.ropensci.org"
@@ -97,7 +109,7 @@ VcrResponse <- R6::R6Class(
         if (inherits(body, "list")) {
           body <- paste(names(body), body, sep = "=", collapse = ",")
         }
-        self$body <- body
+        self$body <- if (is.character(body)) enc2utf8(body) else body
       }
       if (!missing(http_version)) {
         self$http_version <- extract_http_version(http_version)
@@ -182,35 +194,6 @@ VcrResponse <- R6::R6Class(
     is_compressed = function() {
        self$content_encoding() %in% c("gzip", "deflate")
     }
-
-    # Decodes the compressed body and deletes evidence that it was ever compressed.
-    # raises an error if the content encoding is not a known encoding.
-    # decompress = function() {
-    #   new_body <- self$decompress_(self$body, self$content_encoding())
-    #   self$body <- new_body
-    #   self$update_content_length_header()
-    #   self$delete_header('content-encoding')
-    # },
-
-    # # used internally by `decompress()`
-    # decompress_ = function(body, type) {
-    #   unless HAVE_ZLIB
-    #     warning("VCR: cannot decompress response; Zlib not available")
-    #   end
-
-    #   switch(
-    #     type,
-    #     gzip = {
-    #       args = [StringIO.new(body)]
-    #       args << { :encoding => 'ASCII-8BIT' } if ''.respond_to?(:encoding)
-    #       yield Zlib::GzipReader.new(*args).read
-    #     },
-    #     deflate = yield Zlib::Inflate.inflate(body)
-    #     identity = NULL,
-    #     stop('UnknownContentEncodingError: unknown content encoding: ', type)
-    #   )
-    # }
-
   )
 )
 
@@ -222,47 +205,3 @@ extract_http_version <- function(x) {
     return(x)
   }
 }
-
-
-# vcr_request_httr <- function(x) {
-#   Request$new(
-#     x$request$method,
-#     x$url,
-#     x$body, # FIXME: body not a field, probably index to x$request$fields
-#     as.list(x$request$headers),
-#     self$cassette_opts
-#   )
-# }
-
-# vcr_request_crul <- function(x) {
-#   Request$new(
-#     x$request$method,
-#     x$url,
-#     x$body,
-#     x$request_headers,
-#     self$cassette_opts
-#   )
-# }
-
-
-
-# vcr_response_httr <- function(x) {
-#   VcrResponse$new(
-#     httr::http_status(x),
-#     x$headers,
-#     httr::content(x, encoding = "UTF-8"),
-#     x$all_headers[[1]]$version,
-#     super$cassette$cassette_opts
-#   )
-# }
-
-# vcr_response_crul <- function(x) {
-#   VcrResponse$new(
-#     x$status_http(),
-#     headers = x$response_headers,
-#     body = rawToChar(x$content),
-#     http_version = x$response_headers$status,
-#     self$cassette_opts
-#   )
-# }
-
