@@ -1,5 +1,6 @@
 context("use_cassette: write to disk")
 
+vcr_configure_reset()
 tmpdir_wdp <- file.path(tempdir(), "write_disk_path")
 vcr_configure(dir = tmpdir_wdp)
 
@@ -11,18 +12,18 @@ test_that("fails well if write_disk_path not set", {
   library(crul)
   f <- tempfile(fileext = ".json")
   expect_error(
-    use_cassette("write_disk_path_not_set_crul", {
+    sw(use_cassette("write_disk_path_not_set_crul", {
       out <- HttpClient$new("https://httpbin.org/get")$get(disk = f)
-    }),
+    })),
     "write_disk_path must be given"
   )
 
   library(httr)
   g <- tempfile(fileext = ".json")
   expect_error(
-    use_cassette("write_disk_path_not_set_httr", {
+    sw(use_cassette("write_disk_path_not_set_httr", {
       out <- GET("https://httpbin.org/get", write_disk(g, TRUE))
-    }),
+    })),
     "write_disk_path must be given"
   )
 })
